import torch.nn as nn
import torch.utils.data
import torch.nn.functional as F
from geonet_util import GeoNetEncoder

class get_model(nn.Module):
    def __init__(self, k=2, channels=7202):
        super(get_model, self).__init__()
        self.feat = GeoNetEncoder(global_feat=True, channel=channels)
        self.fc1 = nn.Linear(512, 256)
        self.fc2 = nn.Linear(256, 64)
        self.fc3 = nn.Linear(64, k)
        self.dropout = nn.Dropout(p=0.4)
        self.bn1 = nn.BatchNorm1d(256)
        self.bn2 = nn.BatchNorm1d(64)
        self.relu = nn.ReLU()

    def forward(self, x):
        x = self.feat(x)
        #print(x.sum())
        # x = x.transpose(2,1)
        x = F.relu(self.bn1(self.fc1(x)))
        x = F.relu(self.bn2(self.dropout(self.fc2(x))))
        x = self.fc3(x)
        #print(x)
        x = F.log_softmax(x, dim=1)
        return x

class get_loss(torch.nn.Module):
    def __init__(self):
        super(get_loss, self).__init__()

    def forward(self, pred, target):
        loss = F.nll_loss(pred, target)
        return loss