import torch
import torch.nn as nn
import torch.nn.parallel
import torch.utils.data
from torch.autograd import Variable
import numpy as np
import torch.nn.functional as F

class GeoNetEncoder(nn.Module):
    def __init__(self, global_feat=True, channel=3):
        super(GeoNetEncoder, self).__init__()
        self.conv1 = torch.nn.Conv1d(channel, 64, 1)
        self.conv2 = torch.nn.Conv1d(64, 128, 1)
        self.conv3 = torch.nn.Conv1d(128, 512, 1)
        self.bn1 = nn.BatchNorm1d(64)
        self.bn2 = nn.BatchNorm1d(128)
        self.bn3 = nn.BatchNorm1d(512)
        self.global_feat = global_feat

    def forward(self, x):
        B, D, N = x.size()
        #print(self.conv1(x))
        #print(self.bn1(self.conv1(x)))
        x = F.relu(self.bn1(self.conv1(x)))
        #print(x)

        pointfeat = x
        x = F.relu(self.bn2(self.conv2(x)))
        x = self.bn3(self.conv3(x))
        x = torch.max(x, 2, keepdim=True)[0]
        x = x.view(-1, 512)
        if self.global_feat:
            return x
        else:
            x = x.view(-1, 512, 1).repeat(1, 1, N)
            return torch.cat([x, pointfeat], 1)
